function M_local = matriz_local(l,m,n,o,k)
% Cria a matriz local de condutividade do elemento tetradrico de
% coordenadas l, m, n, o.
%
% IN: l, m, n, o: coordenadas no formato [x y z].
%     k: matriz de condutividade no formato [Kxx Kyy Kzz].
%        A matriz de condutividade foi particularizada para o caso
%        isotrpico.
%
% OUT: M_local: vetor linha que representa a matriz local do elemento,
%               de dimenso 1x16.
    
    % volume
    V = [1 l(1) l(2) l(3); 1 m(1) m(2) m(3); 1 n(1) n(2) n(3); 1 o(1) o(2) o(3)];
    v = (1/6)*abs(det(V));  
    
    % calculo dos beta: beta = [b_l b_m b_n b_o]
    beta = zeros(1,4);
    beta(1) = -n(2)*o(3) - m(2)*n(3) - o(2)*m(3) + n(2)*m(3) + m(2)*o(3) + o(2)*n(3);
    beta(2) = n(2)*o(3) + l(2)*n(3) + o(2)*l(3) - n(2)*l(3) - l(2)*o(3) - o(2)*n(3);
    beta(3) = -m(2)*o(3) - l(2)*m(3) - o(2)*l(3) + m(2)*l(3) + l(2)*o(3) + o(2)*m(3);
    beta(4) = m(2)*n(3) + l(2)*m(3) + n(2)*l(3) - m(2)*l(3) - l(2)*n(3) - n(2)*m(3);
    
    % calculo dos gamma
    gamma = zeros(1,4);
    gamma(1) = n(1)*o(3) + m(1)*n(3) + o(1)*m(3) - n(1)*m(3) - m(1)*o(3) - o(1)*n(3);
    gamma(2) = -n(1)*o(3) - l(1)*n(3) - o(1)*l(3) + n(1)*l(3) + l(1)*o(3) + o(1)*n(3);
    gamma(3) = m(1)*o(3) + l(1)*m(3) + o(1)*l(3) - m(1)*l(3) - l(1)*o(3) - o(1)*m(3);
    gamma(4) = -m(1)*n(3) - l(1)*m(3) - n(1)*l(3) + m(1)*l(3) + l(1)*n(3) + n(1)*m(3);
    
    % calculo dos delta
    delta = zeros(1,4);
    delta(1) = -n(1)*o(2) - m(1)*n(2) - o(1)*m(2) + n(1)*m(2) + m(1)*o(2) + o(1)*n(2);
    delta(2) = n(1)*o(2) + l(1)*n(2) + o(1)*l(2) - n(1)*l(2) - l(1)*o(2) - o(1)*n(2);
    delta(3) = -m(1)*o(2) - l(1)*m(2) - o(1)*l(2) + m(1)*l(2) + l(1)*o(2) + o(1)*m(2);
    delta(4) = m(1)*n(2) + l(1)*m(2) + n(1)*l(2) - m(1)*l(2) - l(1)*n(2) - n(1)*m(2);
    
    % matriz de condutividade
    sigma = eye(3).*k;
    
    % matriz M
    M = [beta(1) beta(2) beta(3) beta(4); 
        gamma(1) gamma(2) gamma(3) gamma(4); 
        delta(1) delta(2) delta(3) delta(4)];
   
    % calculo da matriz local
    M_local = 1/(36*v)*transpose(M)*sigma*M;
    M_local = reshape(M_local, [1 16]);
end